@@ -3,8 +3,9 @@ set -e
 set -x
 
 touch ChangeLog
-autopoint
+autopoint --force
 libtoolize --automake --copy
+intltoolize --copy --force
 aclocal -I m4
 autoheader
 automake --add-missing --copy
